==> ejc-ztpcdata-impl-3.0.0-20251018.021453-95-sources.jar: com/ejianc/idmdata/orgcenter/controller/ExternalController.java <==
package com.ejianc.idmdata.orgcenter.controller;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.share.vo.SupplierVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.idmdata.orgcenter.service.IExternalService;
import com.ejianc.idmdata.orgcenter.vo.ActRuTaskVO;
import com.ejianc.idmdata.orgcenter.vo.AttachmentVO;
import com.ejianc.idmdata.orgcenter.vo.ButtonVO;
import com.ejianc.idmdata.orgcenter.vo.IdeModuleVO;
import com.ejianc.ztpcdata.vo.EmployeeVO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping("external")
public class ExternalController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IExternalService externalService;
    @Autowired
    private IOrgApi orgApi;

    @PostMapping("/getButton")
    @ResponseBody
    public CommonResponse<List<ButtonVO>> getButton(@RequestBody Map<String, Object> params) {
        return CommonResponse.success(externalService.getButton(params));
    }

    @PostMapping("/getButtonCount")
    @ResponseBody
    public CommonResponse<Integer> getButtonCount() {
        return CommonResponse.success(externalService.getButtonCount());
    }

    @PostMapping("/getFileId")
    @ResponseBody
    public CommonResponse<List<AttachmentVO>> getFileId(@RequestBody Map<String, Object> params) {
        return CommonResponse.success(externalService.getFileId(params));
    }

    @PostMapping("/getByBizKey")
    @ResponseBody
    public CommonResponse<List<ActRuTaskVO>> getByBizKey(String businessKey) {
        return CommonResponse.success(externalService.getByBizKey(businessKey));
    }

    @PostMapping("/getMyPageInfo")
    @ResponseBody
    public CommonResponse<List<IdeModuleVO>> getMyPageInfo(String appId, String code) {
        return CommonResponse.success(externalService.getMyPageInfo(appId, code));
    }

    @PostMapping("/getOrgIdByOrgCode")
    @ResponseBody
    public CommonResponse<List<Long>> getOrgIdByOrgCode(String orgCode) {
        return CommonResponse.success(externalService.getOrgIdByOrgCode(orgCode));
    }

    @PostMapping("/getMapProjLocal")
    @ResponseBody
    public CommonResponse<List<Map<String, Object>>> getMapProjLocal() {
        return CommonResponse.success(externalService.getMapProjLocal());
    }

    @PostMapping("/queryAllDept")
    @ResponseBody
    public CommonResponse<List<Map<String, Object>>> queryAllDept() {
        return CommonResponse.success(externalService.queryAllDept());
    }

    @PostMapping("/queryAllDeptCondition")
    @ResponseBody
    public CommonResponse<List<Map<String, Object>>> queryAllDeptCondition(String orgId) {
        return CommonResponse.success(externalService.queryAllDeptCondition(orgId));
    }

    @PostMapping("/getMapAllEmployee")
    @ResponseBody
    public CommonResponse<List<Map<String, Object>>> getMapAllEmployee() {
        return CommonResponse.success(externalService.getMapAllEmployee());
    }

    @PostMapping("/getAttachmentBySourceIdAndSourceType")
    @ResponseBody
    public CommonResponse<List<Map<String, Object>>> getAttachmentBySourceIdAndSourceType(Long sourceId,String sourceType) {
        return CommonResponse.success(externalService.getAttachmentBySourceIdAndSourceType(sourceId,sourceType));
    }

    @PostMapping("/getOrgList")
    @ResponseBody
    public CommonResponse<List<OrgVO>> getOrgList(Integer orgType, Integer projectState, Long parentOrgId){
        return CommonResponse.success(externalService.getOrgList(orgType,projectState,parentOrgId));
    }

    @PostMapping("/getEmployeeByName")
    @ResponseBody
    public CommonResponse<List<EmployeeVO>> getEmployeeByName(@RequestBody List<String> names) {
        return CommonResponse.success(externalService.getEmployeeByName(names));
    }

    @PostMapping("/querySupplierByName")
    @ResponseBody
    CommonResponse<List<SupplierVO>> querySupplierByName(@RequestParam("name")String name){
        return CommonResponse.success(externalService.querySupplierByName(name));
    }

    @PostMapping("/querySupplierByIds")
    @ResponseBody
    CommonResponse<List<Map<String, Object>>> querySupplierByIds(@RequestParam("ids")String ids){
        List<Map<String, Object>> data = externalService.querySupplierByIds(ids);
        return CommonResponse.success(data);
    }
}

==> ejc-ztpcdata-impl-3.0.0-20251023.023348-101-sources.jar: com/ejianc/idmdata/orgcenter/controller/ExternalController.java <==
package com.ejianc.idmdata.orgcenter.controller;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.share.vo.SupplierVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.idmdata.orgcenter.service.IExternalService;
import com.ejianc.idmdata.orgcenter.vo.ActRuTaskVO;
import com.ejianc.idmdata.orgcenter.vo.AttachmentVO;
import com.ejianc.idmdata.orgcenter.vo.ButtonVO;
import com.ejianc.idmdata.orgcenter.vo.IdeModuleVO;
import com.ejianc.ztpcdata.vo.EmployeeVO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping("external")
public class ExternalController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IExternalService externalService;
    @Autowired
    private IOrgApi orgApi;

    @PostMapping("/getButton")
    @ResponseBody
    public CommonResponse<List<ButtonVO>> getButton(@RequestBody Map<String, Object> params) {
        return CommonResponse.success(externalService.getButton(params));
    }

    @PostMapping("/getButtonCount")
    @ResponseBody
    public CommonResponse<Integer> getButtonCount() {
        return CommonResponse.success(externalService.getButtonCount());
    }

    @PostMapping("/getFileId")
    @ResponseBody
    public CommonResponse<List<AttachmentVO>> getFileId(@RequestBody Map<String, Object> params) {
        return CommonResponse.success(externalService.getFileId(params));
    }

    @PostMapping("/getByBizKey")
    @ResponseBody
    public CommonResponse<List<ActRuTaskVO>> getByBizKey(String businessKey) {
        return CommonResponse.success(externalService.getByBizKey(businessKey));
    }

    @PostMapping("/getMyPageInfo")
    @ResponseBody
    public CommonResponse<List<IdeModuleVO>> getMyPageInfo(String appId, String code) {
        return CommonResponse.success(externalService.getMyPageInfo(appId, code));
    }

    @PostMapping("/getOrgIdByOrgCode")
    @ResponseBody
    public CommonResponse<List<Long>> getOrgIdByOrgCode(String orgCode) {
        return CommonResponse.success(externalService.getOrgIdByOrgCode(orgCode));
    }

    @PostMapping("/getMapProjLocal")
    @ResponseBody
    public CommonResponse<List<Map<String, Object>>> getMapProjLocal() {
        return CommonResponse.success(externalService.getMapProjLocal());
    }

    @PostMapping("/queryAllDept")
    @ResponseBody
    public CommonResponse<List<Map<String, Object>>> queryAllDept() {
        return CommonResponse.success(externalService.queryAllDept());
    }

    @PostMapping("/queryAllDeptCondition")
    @ResponseBody
    public CommonResponse<List<Map<String, Object>>> queryAllDeptCondition(String orgId) {
        return CommonResponse.success(externalService.queryAllDeptCondition(orgId));
    }

    @PostMapping("/getMapAllEmployee")
    @ResponseBody
    public CommonResponse<List<Map<String, Object>>> getMapAllEmployee() {
        return CommonResponse.success(externalService.getMapAllEmployee());
    }

    @PostMapping("/getAttachmentBySourceIdAndSourceType")
    @ResponseBody
    public CommonResponse<List<Map<String, Object>>> getAttachmentBySourceIdAndSourceType(Long sourceId,String sourceType) {
        return CommonResponse.success(externalService.getAttachmentBySourceIdAndSourceType(sourceId,sourceType));
    }

    @PostMapping("/getOrgList")
    @ResponseBody
    public CommonResponse<List<OrgVO>> getOrgList(Integer orgType, Integer projectState, Long parentOrgId){
        return CommonResponse.success(externalService.getOrgList(orgType,projectState,parentOrgId));
    }

    @PostMapping("/getEmployeeByName")
    @ResponseBody
    public CommonResponse<List<EmployeeVO>> getEmployeeByName(@RequestBody List<String> names) {
        return CommonResponse.success(externalService.getEmployeeByName(names));
    }

    @PostMapping("/querySupplierByName")
    @ResponseBody
    CommonResponse<List<SupplierVO>> querySupplierByName(@RequestParam("name")String name){
        return CommonResponse.success(externalService.querySupplierByName(name));
    }

    @PostMapping("/querySupplierByIds")
    @ResponseBody
    CommonResponse<List<Map<String, Object>>> querySupplierByIds(@RequestBody String ids){
        List<Map<String, Object>> data = externalService.querySupplierByIds(ids);
        return CommonResponse.success(data);
    }
}
